"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * 使用浏览器原生接口实现的LocalStorage
 */
var LocalStorage_Browser = {
    // 同步
    setItem: function (key, value) {
        localStorage.setItem(key, JSON.stringify(value));
    },
    getItem: function (key) {
        try {
            var raw = localStorage.getItem(key);
            if (raw == null) {
                return null;
            }
            else {
                return JSON.parse(raw);
            }
        }
        catch (e) {
            console.warn('Parse JSON Error when getItem from localStorage: ' + key, localStorage.getItem(key), e);
            return null;
        }
    },
    removeItem: function (key) {
        localStorage.removeItem(key);
    },
    clear: function () {
        localStorage.clear();
    },
    // 异步
    setItemAsync: function (key, value) {
        return new Promise(function (rs, rj) {
            try {
                LocalStorage_Browser.setItem(key, value);
                rs();
            }
            catch (e) {
                rj(e);
            }
        });
    },
    getItemAsync: function (key) {
        return new Promise(function (rs, rj) {
            try {
                rs(LocalStorage_Browser.getItem(key));
            }
            catch (e) {
                rj(e);
            }
        });
    },
    removeItemAsync: function (key) {
        return new Promise(function (rs, rj) {
            try {
                LocalStorage_Browser.removeItem(key);
                rs();
            }
            catch (e) {
                rj(e);
            }
        });
    },
    clearAsync: function () {
        return new Promise(function (rs, rj) {
            try {
                LocalStorage_Browser.clear();
                rs();
            }
            catch (e) {
                rj(e);
            }
        });
    }
};
exports.default = LocalStorage_Browser;
