"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * 使用wx.xxStorage接口实现的LocalStorage
 */
var LocalStorage_Weapp = {
    // 同步
    setItem: function (key, value) {
        return wx.setStorageSync(key, JSON.stringify(value));
    },
    getItem: function (key) {
        var raw = wx.getStorageSync(key);
        try {
            if (raw == null || raw == '') {
                return null;
            }
            else {
                return JSON.parse(raw);
            }
        }
        catch (e) {
            console.warn('Parse JSON Error when getItem from localStorage: ' + key, raw, e);
            return null;
        }
    },
    removeItem: function (key) {
        wx.removeStorageSync(key);
    },
    clear: function () {
        wx.clearStorageSync();
    },
    // 异步
    setItemAsync: function (key, value) {
        return new Promise(function (rs, rj) {
            wx.setStorage({
                key: key,
                data: JSON.stringify(value),
                success: function (res) {
                    rs(res);
                },
                fail: function (error) {
                    rj(error);
                }
            });
        });
    },
    getItemAsync: function (key) {
        return new Promise(function (rs, rj) {
            wx.getStorage({
                key: key,
                success: function (res) {
                    try {
                        if (res == null || res == '') {
                            rs(null);
                        }
                        else {
                            rs(JSON.parse(res));
                        }
                    }
                    catch (e) {
                        console.warn('Parse JSON Error when getItemAsync from localStorage: ' + key, res, e);
                        rs(null);
                    }
                },
                fail: function (error) {
                    rj(error);
                }
            });
        });
    },
    removeItemAsync: function (key) {
        return new Promise(function (rs, rj) {
            wx.removeStorage({
                key: key,
                success: function (res) {
                    rs(res);
                },
                fail: function (error) {
                    rj(error);
                }
            });
        });
    },
    clearAsync: function () {
        return wx.clearStorage();
    }
};
exports.default = LocalStorage_Weapp;
